"""
# Vlsir Bindings Unit Tests 
"""

# Import the package under test
import vlsir


def test_version():
    assert vlsir.__version__ == "2.0.dev0"


def test_sim():
    # Test creation of a `vlsir.spice.SimInput`

    from vlsir.circuit_pb2 import (
        Module,
        Signal,
        Connection,
        ConnectionTarget,
        Port,
        Instance,
    )
    from vlsir.utils_pb2 import Reference, QualifiedName

    inp = vlsir.spice.SimInput()
    inp.pkg.modules.append(
        Module(
            name="top",
            ports=[Port(direction="NONE", signal="VSS")],
            signals=[Signal(name="1", width=1), Signal(name="VSS", width=1)],
            instances=[
                Instance(
                    name="r1",
                    module=Reference(
                        external=QualifiedName(
                            domain="vlsir.primitives", name="resistor"
                        )
                    ),
                    connections=[
                        Connection(portname="p", target=ConnectionTarget(sig="1")),
                        Connection(portname="n", target=ConnectionTarget(sig="VSS")),
                    ],
                )
            ],
        )
    )
    inp.top = "top"


def test_primitives1():
    # Load up and test the primitive definitions
    from vlsir import primitives

    assert isinstance(primitives.pkg, vlsir.circuit.Package)
    assert primitives.pkg.domain == "vlsir.primitives"
    assert isinstance(primitives.pkg.desc, str)
    assert len(primitives.pkg.desc)
    assert len(primitives.pkg.modules) == 0
    assert len(primitives.pkg.ext_modules) > 1

    assert isinstance(primitives.resistor, vlsir.circuit.ExternalModule)
    assert isinstance(primitives.dct["resistor"], vlsir.circuit.ExternalModule)
    assert primitives.resistor is primitives.dct["resistor"]

    assert isinstance(primitives.capacitor, vlsir.circuit.ExternalModule)
    assert isinstance(primitives.dct["capacitor"], vlsir.circuit.ExternalModule)
    assert primitives.capacitor is primitives.dct["capacitor"]

    assert isinstance(primitives.inductor, vlsir.circuit.ExternalModule)
    assert isinstance(primitives.dct["inductor"], vlsir.circuit.ExternalModule)
    assert primitives.inductor is primitives.dct["inductor"]

    assert isinstance(primitives.mos, vlsir.circuit.ExternalModule)
    assert isinstance(primitives.dct["mos"], vlsir.circuit.ExternalModule)
    assert primitives.mos is primitives.dct["mos"]

    assert isinstance(primitives.bipolar, vlsir.circuit.ExternalModule)
    assert isinstance(primitives.dct["bipolar"], vlsir.circuit.ExternalModule)
    assert primitives.bipolar is primitives.dct["bipolar"]

    assert isinstance(primitives.diode, vlsir.circuit.ExternalModule)
    assert isinstance(primitives.dct["diode"], vlsir.circuit.ExternalModule)
    assert primitives.diode is primitives.dct["diode"]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tech.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\ntech.proto\x12\nvlsir.tech"h\n\nTechnology\x12\x0c\n\x04name\x18\x01 \x01(\t\x12%\n\x08packages\x18\x0b \x03(\x0b\x32\x13.vlsir.tech.Package\x12%\n\x06layers\x18\x65 \x03(\x0b\x32\x15.vlsir.tech.LayerInfo"\x17\n\x07Package\x12\x0c\n\x04name\x18\x01 \x01(\t"O\n\x0cLayerPurpose\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12*\n\x04type\x18\x02 \x01(\x0e\x32\x1c.vlsir.tech.LayerPurposeType"f\n\tLayerInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12)\n\x07purpose\x18\x0b \x01(\x0b\x32\x18.vlsir.tech.LayerPurpose\x12\r\n\x05index\x18\x15 \x01(\x04\x12\x11\n\tsub_index\x18\x1f \x01(\x04*^\n\x10LayerPurposeType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\t\n\x05LABEL\x10\x01\x12\x0b\n\x07\x44RAWING\x10\x02\x12\x07\n\x03PIN\x10\x03\x12\x0f\n\x0bOBSTRUCTION\x10\x04\x12\x0b\n\x07OUTLINE\x10\x05\x62\x06proto3'
)

_LAYERPURPOSETYPE = DESCRIPTOR.enum_types_by_name["LayerPurposeType"]
LayerPurposeType = enum_type_wrapper.EnumTypeWrapper(_LAYERPURPOSETYPE)
UNKNOWN = 0
LABEL = 1
DRAWING = 2
PIN = 3
OBSTRUCTION = 4
OUTLINE = 5


_TECHNOLOGY = DESCRIPTOR.message_types_by_name["Technology"]
_PACKAGE = DESCRIPTOR.message_types_by_name["Package"]
_LAYERPURPOSE = DESCRIPTOR.message_types_by_name["LayerPurpose"]
_LAYERINFO = DESCRIPTOR.message_types_by_name["LayerInfo"]
Technology = _reflection.GeneratedProtocolMessageType(
    "Technology",
    (_message.Message,),
    {
        "DESCRIPTOR": _TECHNOLOGY,
        "__module__": "tech_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.tech.Technology)
    },
)
_sym_db.RegisterMessage(Technology)

Package = _reflection.GeneratedProtocolMessageType(
    "Package",
    (_message.Message,),
    {
        "DESCRIPTOR": _PACKAGE,
        "__module__": "tech_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.tech.Package)
    },
)
_sym_db.RegisterMessage(Package)

LayerPurpose = _reflection.GeneratedProtocolMessageType(
    "LayerPurpose",
    (_message.Message,),
    {
        "DESCRIPTOR": _LAYERPURPOSE,
        "__module__": "tech_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.tech.LayerPurpose)
    },
)
_sym_db.RegisterMessage(LayerPurpose)

LayerInfo = _reflection.GeneratedProtocolMessageType(
    "LayerInfo",
    (_message.Message,),
    {
        "DESCRIPTOR": _LAYERINFO,
        "__module__": "tech_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.tech.LayerInfo)
    },
)
_sym_db.RegisterMessage(LayerInfo)

if _descriptor._USE_C_DESCRIPTORS == False:

    DESCRIPTOR._options = None
    _LAYERPURPOSETYPE._serialized_start = 342
    _LAYERPURPOSETYPE._serialized_end = 436
    _TECHNOLOGY._serialized_start = 26
    _TECHNOLOGY._serialized_end = 130
    _PACKAGE._serialized_start = 132
    _PACKAGE._serialized_end = 155
    _LAYERPURPOSE._serialized_start = 157
    _LAYERPURPOSE._serialized_end = 236
    _LAYERINFO._serialized_start = 238
    _LAYERINFO._serialized_end = 340
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: layout/tetris.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import utils_pb2 as utils__pb2
from layout import raw_pb2 as layout_dot_raw__pb2
import circuit_pb2 as circuit__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x13layout/tetris.proto\x12\x0cvlsir.tetris\x1a\x0butils.proto\x1a\x10layout/raw.proto\x1a\rcircuit.proto"i\n\x07Library\x12\x0e\n\x06\x64omain\x18\x01 \x01(\t\x12!\n\x05\x63\x65lls\x18\n \x03(\x0b\x32\x12.vlsir.tetris.Cell\x12+\n\x06\x61uthor\x18\x14 \x01(\x0b\x32\x1b.vlsir.utils.AuthorMetadata"\xb8\x01\n\x04\x43\x65ll\x12\x0c\n\x04name\x18\x01 \x01(\t\x12+\n\tinterface\x18\n \x01(\x0b\x32\x18.vlsir.circuit.Interface\x12%\n\x06module\x18\x0b \x01(\x0b\x32\x15.vlsir.circuit.Module\x12(\n\x08\x61\x62stract\x18\x0c \x01(\x0b\x32\x16.vlsir.tetris.Abstract\x12$\n\x06layout\x18\r \x01(\x0b\x32\x14.vlsir.tetris.Layout"\xbc\x01\n\x06Layout\x12\x0c\n\x04name\x18\x01 \x01(\t\x12&\n\x07outline\x18\n \x01(\x0b\x32\x15.vlsir.tetris.Outline\x12)\n\tinstances\x18\x14 \x03(\x0b\x32\x16.vlsir.tetris.Instance\x12)\n\x0b\x61ssignments\x18\x15 \x03(\x0b\x32\x14.vlsir.tetris.Assign\x12&\n\x04\x63uts\x18\x16 \x03(\x0b\x32\x18.vlsir.tetris.TrackCross";\n\x06\x41ssign\x12\x0b\n\x03net\x18\x01 \x01(\t\x12$\n\x02\x61t\x18\x02 \x01(\x0b\x32\x18.vlsir.tetris.TrackCross"Z\n\nTrackCross\x12%\n\x05track\x18\x01 \x01(\x0b\x32\x16.vlsir.tetris.TrackRef\x12%\n\x05\x63ross\x18\x02 \x01(\x0b\x32\x16.vlsir.tetris.TrackRef"(\n\x08TrackRef\x12\r\n\x05layer\x18\x01 \x01(\x03\x12\r\n\x05track\x18\x02 \x01(\x03"/\n\x07Outline\x12\t\n\x01x\x18\x01 \x03(\x03\x12\t\n\x01y\x18\x02 \x03(\x03\x12\x0e\n\x06metals\x18\x03 \x01(\x03"k\n\x08\x41\x62stract\x12\x0c\n\x04name\x18\x01 \x01(\t\x12&\n\x07outline\x18\n \x01(\x0b\x32\x15.vlsir.tetris.Outline\x12)\n\x05ports\x18\x14 \x03(\x0b\x32\x1a.vlsir.tetris.AbstractPort"\x97\x04\n\x0c\x41\x62stractPort\x12\x0b\n\x03net\x18\x01 \x01(\t\x12\x33\n\x04\x65\x64ge\x18\n \x01(\x0b\x32#.vlsir.tetris.AbstractPort.EdgePortH\x00\x12<\n\tztop_edge\x18\x0b \x01(\x0b\x32\'.vlsir.tetris.AbstractPort.ZTopEdgePortH\x00\x12:\n\nztop_inner\x18\x0c \x01(\x0b\x32$.vlsir.tetris.AbstractPort.ZTopInnerH\x00\x1a\x64\n\x08\x45\x64gePort\x12%\n\x05track\x18\x01 \x01(\x0b\x32\x16.vlsir.tetris.TrackRef\x12\x31\n\x04side\x18\x02 \x01(\x0e\x32#.vlsir.tetris.AbstractPort.PortSide\x1av\n\x0cZTopEdgePort\x12\r\n\x05track\x18\x01 \x01(\x03\x12\x31\n\x04side\x18\x02 \x01(\x0e\x32#.vlsir.tetris.AbstractPort.PortSide\x12$\n\x04into\x18\x03 \x01(\x0b\x32\x16.vlsir.tetris.TrackRef\x1a\x33\n\tZTopInner\x12&\n\x04locs\x18\x01 \x03(\x0b\x32\x18.vlsir.tetris.TrackCross"0\n\x08PortSide\x12\x12\n\x0e\x42OTTOM_OR_LEFT\x10\x00\x12\x10\n\x0cTOP_OR_RIGHT\x10\x01\x42\x06\n\x04kind"\x8d\x01\n\x08Instance\x12\x0c\n\x04name\x18\x01 \x01(\t\x12$\n\x04\x63\x65ll\x18\x03 \x01(\x0b\x32\x16.vlsir.utils.Reference\x12 \n\x03loc\x18\x04 \x01(\x0b\x32\x13.vlsir.tetris.Place\x12\x15\n\rreflect_horiz\x18\x06 \x01(\x08\x12\x14\n\x0creflect_vert\x18\x07 \x01(\x08"X\n\x05Place\x12\x1f\n\x03\x61\x62s\x18\x01 \x01(\x0b\x32\x10.vlsir.raw.PointH\x00\x12%\n\x03rel\x18\x02 \x01(\x0b\x32\x16.vlsir.tetris.RelPlaceH\x00\x42\x07\n\x05place"\n\n\x08RelPlace"\xce\x01\n\x05Stack\x12\x1f\n\x05units\x18\x01 \x01(\x0e\x32\x10.vlsir.raw.Units\x12*\n\x04prim\x18\x02 \x01(\x0b\x32\x1c.vlsir.tetris.PrimitiveLayer\x12(\n\x06metals\x18\x03 \x03(\x0b\x32\x18.vlsir.tetris.MetalLayer\x12$\n\x04vias\x18\x04 \x03(\x0b\x32\x16.vlsir.tetris.ViaLayer\x12(\n\x0e\x62oundary_layer\x18\x0b \x01(\x0b\x32\x10.vlsir.raw.Layer"{\n\tLayerEnum\x12/\n\x04type\x18\x01 \x01(\x0e\x32!.vlsir.tetris.LayerEnum.LayerType\x12\r\n\x05index\x18\x02 \x01(\x03".\n\tLayerType\x12\r\n\tPRIMITIVE\x10\x00\x12\t\n\x05METAL\x10\x01\x12\x07\n\x03VIA\x10\x02"\xd1\x02\n\nMetalLayer\x12\x0c\n\x04name\x18\x01 \x01(\t\x12)\n\x03\x64ir\x18\x02 \x01(\x0e\x32\x1c.vlsir.tetris.MetalLayer.Dir\x12\x0f\n\x07\x63utsize\x18\x03 \x01(\x03\x12(\n\x07\x65ntries\x18\x04 \x03(\x0b\x32\x17.vlsir.tetris.TrackSpec\x12\x0e\n\x06offset\x18\x05 \x01(\x03\x12\x0f\n\x07overlap\x18\x06 \x01(\x03\x12\x0c\n\x04\x66lip\x18\x07 \x01(\x08\x12\x34\n\x04prim\x18\x08 \x01(\x0e\x32&.vlsir.tetris.MetalLayer.PrimitiveMode\x12\x1d\n\x03raw\x18\x0b \x01(\x0b\x32\x10.vlsir.raw.Layer"\x1a\n\x03\x44ir\x12\t\n\x05HORIZ\x10\x00\x12\x08\n\x04VERT\x10\x01"/\n\rPrimitiveMode\x12\x08\n\x04PRIM\x10\x00\x12\t\n\x05SPLIT\x10\x01\x12\t\n\x05STACK\x10\x02"\xa3\x01\n\x08ViaLayer\x12\x0c\n\x04name\x18\x01 \x01(\t\x12$\n\x03top\x18\x02 \x01(\x0b\x32\x17.vlsir.tetris.LayerEnum\x12$\n\x03\x62ot\x18\x03 \x01(\x0b\x32\x17.vlsir.tetris.LayerEnum\x12\x1e\n\x04size\x18\x04 \x01(\x0b\x32\x10.vlsir.tetris.Xy\x12\x1d\n\x03raw\x18\x0b \x01(\x0b\x32\x10.vlsir.raw.Layer"3\n\x0ePrimitiveLayer\x12!\n\x07pitches\x18\x01 \x01(\x0b\x32\x10.vlsir.tetris.Xy"\xce\x02\n\tTrackSpec\x12\x33\n\x05\x65ntry\x18\x01 \x01(\x0b\x32".vlsir.tetris.TrackSpec.TrackEntryH\x00\x12\x30\n\x06repeat\x18\x02 \x01(\x0b\x32\x1e.vlsir.tetris.TrackSpec.RepeatH\x00\x1a\x84\x01\n\nTrackEntry\x12;\n\x05ttype\x18\x01 \x01(\x0e\x32,.vlsir.tetris.TrackSpec.TrackEntry.TrackType\x12\r\n\x05width\x18\x02 \x01(\x03"*\n\tTrackType\x12\x07\n\x03GAP\x10\x00\x12\n\n\x06SIGNAL\x10\x01\x12\x08\n\x04RAIL\x10\x02\x1aK\n\x06Repeat\x12\x33\n\x07\x65ntries\x18\x01 \x03(\x0b\x32".vlsir.tetris.TrackSpec.TrackEntry\x12\x0c\n\x04nrep\x18\x02 \x01(\x03\x42\x06\n\x04spec"\x1a\n\x02Xy\x12\t\n\x01x\x18\x01 \x01(\x03\x12\t\n\x01y\x18\x02 \x01(\x03\x62\x06proto3'
)


_LIBRARY = DESCRIPTOR.message_types_by_name["Library"]
_CELL = DESCRIPTOR.message_types_by_name["Cell"]
_LAYOUT = DESCRIPTOR.message_types_by_name["Layout"]
_ASSIGN = DESCRIPTOR.message_types_by_name["Assign"]
_TRACKCROSS = DESCRIPTOR.message_types_by_name["TrackCross"]
_TRACKREF = DESCRIPTOR.message_types_by_name["TrackRef"]
_OUTLINE = DESCRIPTOR.message_types_by_name["Outline"]
_ABSTRACT = DESCRIPTOR.message_types_by_name["Abstract"]
_ABSTRACTPORT = DESCRIPTOR.message_types_by_name["AbstractPort"]
_ABSTRACTPORT_EDGEPORT = _ABSTRACTPORT.nested_types_by_name["EdgePort"]
_ABSTRACTPORT_ZTOPEDGEPORT = _ABSTRACTPORT.nested_types_by_name["ZTopEdgePort"]
_ABSTRACTPORT_ZTOPINNER = _ABSTRACTPORT.nested_types_by_name["ZTopInner"]
_INSTANCE = DESCRIPTOR.message_types_by_name["Instance"]
_PLACE = DESCRIPTOR.message_types_by_name["Place"]
_RELPLACE = DESCRIPTOR.message_types_by_name["RelPlace"]
_STACK = DESCRIPTOR.message_types_by_name["Stack"]
_LAYERENUM = DESCRIPTOR.message_types_by_name["LayerEnum"]
_METALLAYER = DESCRIPTOR.message_types_by_name["MetalLayer"]
_VIALAYER = DESCRIPTOR.message_types_by_name["ViaLayer"]
_PRIMITIVELAYER = DESCRIPTOR.message_types_by_name["PrimitiveLayer"]
_TRACKSPEC = DESCRIPTOR.message_types_by_name["TrackSpec"]
_TRACKSPEC_TRACKENTRY = _TRACKSPEC.nested_types_by_name["TrackEntry"]
_TRACKSPEC_REPEAT = _TRACKSPEC.nested_types_by_name["Repeat"]
_XY = DESCRIPTOR.message_types_by_name["Xy"]
_ABSTRACTPORT_PORTSIDE = _ABSTRACTPORT.enum_types_by_name["PortSide"]
_LAYERENUM_LAYERTYPE = _LAYERENUM.enum_types_by_name["LayerType"]
_METALLAYER_DIR = _METALLAYER.enum_types_by_name["Dir"]
_METALLAYER_PRIMITIVEMODE = _METALLAYER.enum_types_by_name["PrimitiveMode"]
_TRACKSPEC_TRACKENTRY_TRACKTYPE = _TRACKSPEC_TRACKENTRY.enum_types_by_name["TrackType"]
Library = _reflection.GeneratedProtocolMessageType(
    "Library",
    (_message.Message,),
    {
        "DESCRIPTOR": _LIBRARY,
        "__module__": "layout.tetris_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.tetris.Library)
    },
)
_sym_db.RegisterMessage(Library)

Cell = _reflection.GeneratedProtocolMessageType(
    "Cell",
    (_message.Message,),
    {
        "DESCRIPTOR": _CELL,
        "__module__": "layout.tetris_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.tetris.Cell)
    },
)
_sym_db.RegisterMessage(Cell)

Layout = _reflection.GeneratedProtocolMessageType(
    "Layout",
    (_message.Message,),
    {
        "DESCRIPTOR": _LAYOUT,
        "__module__": "layout.tetris_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.tetris.Layout)
    },
)
_sym_db.RegisterMessage(Layout)

Assign = _reflection.GeneratedProtocolMessageType(
    "Assign",
    (_message.Message,),
    {
        "DESCRIPTOR": _ASSIGN,
        "__module__": "layout.tetris_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.tetris.Assign)
    },
)
_sym_db.RegisterMessage(Assign)

TrackCross = _reflection.GeneratedProtocolMessageType(
    "TrackCross",
    (_message.Message,),
    {
        "DESCRIPTOR": _TRACKCROSS,
        "__module__": "layout.tetris_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.tetris.TrackCross)
    },
)
_sym_db.RegisterMessage(TrackCross)

TrackRef = _reflection.GeneratedProtocolMessageType(
    "TrackRef",
    (_message.Message,),
    {
        "DESCRIPTOR": _TRACKREF,
        "__module__": "layout.tetris_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.tetris.TrackRef)
    },
)
_sym_db.RegisterMessage(TrackRef)

Outline = _reflection.GeneratedProtocolMessageType(
    "Outline",
    (_message.Message,),
    {
        "DESCRIPTOR": _OUTLINE,
        "__module__": "layout.tetris_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.tetris.Outline)
    },
)
_sym_db.RegisterMessage(Outline)

Abstract = _reflection.GeneratedProtocolMessageType(
    "Abstract",
    (_message.Message,),
    {
        "DESCRIPTOR": _ABSTRACT,
        "__module__": "layout.tetris_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.tetris.Abstract)
    },
)
_sym_db.RegisterMessage(Abstract)

AbstractPort = _reflection.GeneratedProtocolMessageType(
    "AbstractPort",
    (_message.Message,),
    {
        "EdgePort": _reflection.GeneratedProtocolMessageType(
            "EdgePort",
            (_message.Message,),
            {
                "DESCRIPTOR": _ABSTRACTPORT_EDGEPORT,
                "__module__": "layout.tetris_pb2"
                # @@protoc_insertion_point(class_scope:vlsir.tetris.AbstractPort.EdgePort)
            },
        ),
        "ZTopEdgePort": _reflection.GeneratedProtocolMessageType(
            "ZTopEdgePort",
            (_message.Message,),
            {
                "DESCRIPTOR": _ABSTRACTPORT_ZTOPEDGEPORT,
                "__module__": "layout.tetris_pb2"
                # @@protoc_insertion_point(class_scope:vlsir.tetris.AbstractPort.ZTopEdgePort)
            },
        ),
        "ZTopInner": _reflection.GeneratedProtocolMessageType(
            "ZTopInner",
            (_message.Message,),
            {
                "DESCRIPTOR": _ABSTRACTPORT_ZTOPINNER,
                "__module__": "layout.tetris_pb2"
                # @@protoc_insertion_point(class_scope:vlsir.tetris.AbstractPort.ZTopInner)
            },
        ),
        "DESCRIPTOR": _ABSTRACTPORT,
        "__module__": "layout.tetris_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.tetris.AbstractPort)
    },
)
_sym_db.RegisterMessage(AbstractPort)
_sym_db.RegisterMessage(AbstractPort.EdgePort)
_sym_db.RegisterMessage(AbstractPort.ZTopEdgePort)
_sym_db.RegisterMessage(AbstractPort.ZTopInner)

Instance = _reflection.GeneratedProtocolMessageType(
    "Instance",
    (_message.Message,),
    {
        "DESCRIPTOR": _INSTANCE,
        "__module__": "layout.tetris_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.tetris.Instance)
    },
)
_sym_db.RegisterMessage(Instance)

Place = _reflection.GeneratedProtocolMessageType(
    "Place",
    (_message.Message,),
    {
        "DESCRIPTOR": _PLACE,
        "__module__": "layout.tetris_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.tetris.Place)
    },
)
_sym_db.RegisterMessage(Place)

RelPlace = _reflection.GeneratedProtocolMessageType(
    "RelPlace",
    (_message.Message,),
    {
        "DESCRIPTOR": _RELPLACE,
        "__module__": "layout.tetris_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.tetris.RelPlace)
    },
)
_sym_db.RegisterMessage(RelPlace)

Stack = _reflection.GeneratedProtocolMessageType(
    "Stack",
    (_message.Message,),
    {
        "DESCRIPTOR": _STACK,
        "__module__": "layout.tetris_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.tetris.Stack)
    },
)
_sym_db.RegisterMessage(Stack)

LayerEnum = _reflection.GeneratedProtocolMessageType(
    "LayerEnum",
    (_message.Message,),
    {
        "DESCRIPTOR": _LAYERENUM,
        "__module__": "layout.tetris_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.tetris.LayerEnum)
    },
)
_sym_db.RegisterMessage(LayerEnum)

MetalLayer = _reflection.GeneratedProtocolMessageType(
    "MetalLayer",
    (_message.Message,),
    {
        "DESCRIPTOR": _METALLAYER,
        "__module__": "layout.tetris_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.tetris.MetalLayer)
    },
)
_sym_db.RegisterMessage(MetalLayer)

ViaLayer = _reflection.GeneratedProtocolMessageType(
    "ViaLayer",
    (_message.Message,),
    {
        "DESCRIPTOR": _VIALAYER,
        "__module__": "layout.tetris_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.tetris.ViaLayer)
    },
)
_sym_db.RegisterMessage(ViaLayer)

PrimitiveLayer = _reflection.GeneratedProtocolMessageType(
    "PrimitiveLayer",
    (_message.Message,),
    {
        "DESCRIPTOR": _PRIMITIVELAYER,
        "__module__": "layout.tetris_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.tetris.PrimitiveLayer)
    },
)
_sym_db.RegisterMessage(PrimitiveLayer)

TrackSpec = _reflection.GeneratedProtocolMessageType(
    "TrackSpec",
    (_message.Message,),
    {
        "TrackEntry": _reflection.GeneratedProtocolMessageType(
            "TrackEntry",
            (_message.Message,),
            {
                "DESCRIPTOR": _TRACKSPEC_TRACKENTRY,
                "__module__": "layout.tetris_pb2"
                # @@protoc_insertion_point(class_scope:vlsir.tetris.TrackSpec.TrackEntry)
            },
        ),
        "Repeat": _reflection.GeneratedProtocolMessageType(
            "Repeat",
            (_message.Message,),
            {
                "DESCRIPTOR": _TRACKSPEC_REPEAT,
                "__module__": "layout.tetris_pb2"
                # @@protoc_insertion_point(class_scope:vlsir.tetris.TrackSpec.Repeat)
            },
        ),
        "DESCRIPTOR": _TRACKSPEC,
        "__module__": "layout.tetris_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.tetris.TrackSpec)
    },
)
_sym_db.RegisterMessage(TrackSpec)
_sym_db.RegisterMessage(TrackSpec.TrackEntry)
_sym_db.RegisterMessage(TrackSpec.Repeat)

Xy = _reflection.GeneratedProtocolMessageType(
    "Xy",
    (_message.Message,),
    {
        "DESCRIPTOR": _XY,
        "__module__": "layout.tetris_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.tetris.Xy)
    },
)
_sym_db.RegisterMessage(Xy)

if _descriptor._USE_C_DESCRIPTORS == False:

    DESCRIPTOR._options = None
    _LIBRARY._serialized_start = 83
    _LIBRARY._serialized_end = 188
    _CELL._serialized_start = 191
    _CELL._serialized_end = 375
    _LAYOUT._serialized_start = 378
    _LAYOUT._serialized_end = 566
    _ASSIGN._serialized_start = 568
    _ASSIGN._serialized_end = 627
    _TRACKCROSS._serialized_start = 629
    _TRACKCROSS._serialized_end = 719
    _TRACKREF._serialized_start = 721
    _TRACKREF._serialized_end = 761
    _OUTLINE._serialized_start = 763
    _OUTLINE._serialized_end = 810
    _ABSTRACT._serialized_start = 812
    _ABSTRACT._serialized_end = 919
    _ABSTRACTPORT._serialized_start = 922
    _ABSTRACTPORT._serialized_end = 1457
    _ABSTRACTPORT_EDGEPORT._serialized_start = 1126
    _ABSTRACTPORT_EDGEPORT._serialized_end = 1226
    _ABSTRACTPORT_ZTOPEDGEPORT._serialized_start = 1228
    _ABSTRACTPORT_ZTOPEDGEPORT._serialized_end = 1346
    _ABSTRACTPORT_ZTOPINNER._serialized_start = 1348
    _ABSTRACTPORT_ZTOPINNER._serialized_end = 1399
    _ABSTRACTPORT_PORTSIDE._serialized_start = 1401
    _ABSTRACTPORT_PORTSIDE._serialized_end = 1449
    _INSTANCE._serialized_start = 1460
    _INSTANCE._serialized_end = 1601
    _PLACE._serialized_start = 1603
    _PLACE._serialized_end = 1691
    _RELPLACE._serialized_start = 1693
    _RELPLACE._serialized_end = 1703
    _STACK._serialized_start = 1706
    _STACK._serialized_end = 1912
    _LAYERENUM._serialized_start = 1914
    _LAYERENUM._serialized_end = 2037
    _LAYERENUM_LAYERTYPE._serialized_start = 1991
    _LAYERENUM_LAYERTYPE._serialized_end = 2037
    _METALLAYER._serialized_start = 2040
    _METALLAYER._serialized_end = 2377
    _METALLAYER_DIR._serialized_start = 2302
    _METALLAYER_DIR._serialized_end = 2328
    _METALLAYER_PRIMITIVEMODE._serialized_start = 2330
    _METALLAYER_PRIMITIVEMODE._serialized_end = 2377
    _VIALAYER._serialized_start = 2380
    _VIALAYER._serialized_end = 2543
    _PRIMITIVELAYER._serialized_start = 2545
    _PRIMITIVELAYER._serialized_end = 2596
    _TRACKSPEC._serialized_start = 2599
    _TRACKSPEC._serialized_end = 2933
    _TRACKSPEC_TRACKENTRY._serialized_start = 2716
    _TRACKSPEC_TRACKENTRY._serialized_end = 2848
    _TRACKSPEC_TRACKENTRY_TRACKTYPE._serialized_start = 2806
    _TRACKSPEC_TRACKENTRY_TRACKTYPE._serialized_end = 2848
    _TRACKSPEC_REPEAT._serialized_start = 2850
    _TRACKSPEC_REPEAT._serialized_end = 2925
    _XY._serialized_start = 2935
    _XY._serialized_end = 2961
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: raw.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import utils_pb2 as utils__pb2
from . import circuit_pb2 as circuit__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\traw.proto\x12\tvlsir.raw\x1a\x0butils.proto\x1a\rcircuit.proto"\x1d\n\x05Point\x12\t\n\x01x\x18\x01 \x01(\x03\x12\t\n\x01y\x18\x02 \x01(\x03"(\n\x05Layer\x12\x0e\n\x06number\x18\x01 \x01(\x03\x12\x0f\n\x07purpose\x18\x02 \x01(\x03"]\n\tRectangle\x12\x0b\n\x03net\x18\x01 \x01(\t\x12$\n\nlower_left\x18\x02 \x01(\x0b\x32\x10.vlsir.raw.Point\x12\r\n\x05width\x18\x03 \x01(\x03\x12\x0e\n\x06height\x18\x04 \x01(\x03":\n\x07Polygon\x12\x0b\n\x03net\x18\x01 \x01(\t\x12"\n\x08vertices\x18\x02 \x03(\x0b\x32\x10.vlsir.raw.Point"D\n\x04Path\x12\x0b\n\x03net\x18\x01 \x01(\t\x12 \n\x06points\x18\x02 \x03(\x0b\x32\x10.vlsir.raw.Point\x12\r\n\x05width\x18\x03 \x01(\x03"\x9e\x01\n\x0bLayerShapes\x12\x1f\n\x05layer\x18\x01 \x01(\x0b\x32\x10.vlsir.raw.Layer\x12(\n\nrectangles\x18\x02 \x03(\x0b\x32\x14.vlsir.raw.Rectangle\x12$\n\x08polygons\x18\x03 \x03(\x0b\x32\x12.vlsir.raw.Polygon\x12\x1e\n\x05paths\x18\x04 \x03(\x0b\x32\x0f.vlsir.raw.Path"<\n\x0bTextElement\x12\x0e\n\x06string\x18\x01 \x01(\t\x12\x1d\n\x03loc\x18\x02 \x01(\x0b\x32\x10.vlsir.raw.Point"\xa3\x01\n\x08Instance\x12\x0c\n\x04name\x18\x01 \x01(\t\x12$\n\x04\x63\x65ll\x18\x03 \x01(\x0b\x32\x16.vlsir.utils.Reference\x12)\n\x0forigin_location\x18\x04 \x01(\x0b\x32\x10.vlsir.raw.Point\x12\x14\n\x0creflect_vert\x18\x06 \x01(\x08\x12"\n\x1arotation_clockwise_degrees\x18\x07 \x01(\x05"\x93\x01\n\x06Layout\x12\x0c\n\x04name\x18\x01 \x01(\t\x12&\n\x06shapes\x18\x02 \x03(\x0b\x32\x16.vlsir.raw.LayerShapes\x12&\n\tinstances\x18\x03 \x03(\x0b\x32\x13.vlsir.raw.Instance\x12+\n\x0b\x61nnotations\x18\x04 \x03(\x0b\x32\x16.vlsir.raw.TextElement"\x90\x01\n\x08\x41\x62stract\x12\x0c\n\x04name\x18\x01 \x01(\t\x12#\n\x07outline\x18\x02 \x01(\x0b\x32\x12.vlsir.raw.Polygon\x12&\n\x05ports\x18\x04 \x03(\x0b\x32\x17.vlsir.raw.AbstractPort\x12)\n\tblockages\x18\x05 \x03(\x0b\x32\x16.vlsir.raw.LayerShapes"C\n\x0c\x41\x62stractPort\x12\x0b\n\x03net\x18\x01 \x01(\t\x12&\n\x06shapes\x18\x02 \x03(\x0b\x32\x16.vlsir.raw.LayerShapes"\xb2\x01\n\x04\x43\x65ll\x12\x0c\n\x04name\x18\x01 \x01(\t\x12+\n\tinterface\x18\n \x01(\x0b\x32\x18.vlsir.circuit.Interface\x12%\n\x06module\x18\x0b \x01(\x0b\x32\x15.vlsir.circuit.Module\x12%\n\x08\x61\x62stract\x18\x0c \x01(\x0b\x32\x13.vlsir.raw.Abstract\x12!\n\x06layout\x18\r \x01(\x0b\x32\x11.vlsir.raw.Layout"\x87\x01\n\x07Library\x12\x0e\n\x06\x64omain\x18\x01 \x01(\t\x12\x1f\n\x05units\x18\x02 \x01(\x0e\x32\x10.vlsir.raw.Units\x12\x1e\n\x05\x63\x65lls\x18\n \x03(\x0b\x32\x0f.vlsir.raw.Cell\x12+\n\x06\x61uthor\x18\x14 \x01(\x0b\x32\x1b.vlsir.utils.AuthorMetadata**\n\x05Units\x12\t\n\x05MICRO\x10\x00\x12\x08\n\x04NANO\x10\x01\x12\x0c\n\x08\x41NGSTROM\x10\x02\x62\x06proto3'
)

_UNITS = DESCRIPTOR.enum_types_by_name["Units"]
Units = enum_type_wrapper.EnumTypeWrapper(_UNITS)
MICRO = 0
NANO = 1
ANGSTROM = 2


_POINT = DESCRIPTOR.message_types_by_name["Point"]
_LAYER = DESCRIPTOR.message_types_by_name["Layer"]
_RECTANGLE = DESCRIPTOR.message_types_by_name["Rectangle"]
_POLYGON = DESCRIPTOR.message_types_by_name["Polygon"]
_PATH = DESCRIPTOR.message_types_by_name["Path"]
_LAYERSHAPES = DESCRIPTOR.message_types_by_name["LayerShapes"]
_TEXTELEMENT = DESCRIPTOR.message_types_by_name["TextElement"]
_INSTANCE = DESCRIPTOR.message_types_by_name["Instance"]
_LAYOUT = DESCRIPTOR.message_types_by_name["Layout"]
_ABSTRACT = DESCRIPTOR.message_types_by_name["Abstract"]
_ABSTRACTPORT = DESCRIPTOR.message_types_by_name["AbstractPort"]
_CELL = DESCRIPTOR.message_types_by_name["Cell"]
_LIBRARY = DESCRIPTOR.message_types_by_name["Library"]
Point = _reflection.GeneratedProtocolMessageType(
    "Point",
    (_message.Message,),
    {
        "DESCRIPTOR": _POINT,
        "__module__": "raw_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.raw.Point)
    },
)
_sym_db.RegisterMessage(Point)

Layer = _reflection.GeneratedProtocolMessageType(
    "Layer",
    (_message.Message,),
    {
        "DESCRIPTOR": _LAYER,
        "__module__": "raw_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.raw.Layer)
    },
)
_sym_db.RegisterMessage(Layer)

Rectangle = _reflection.GeneratedProtocolMessageType(
    "Rectangle",
    (_message.Message,),
    {
        "DESCRIPTOR": _RECTANGLE,
        "__module__": "raw_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.raw.Rectangle)
    },
)
_sym_db.RegisterMessage(Rectangle)

Polygon = _reflection.GeneratedProtocolMessageType(
    "Polygon",
    (_message.Message,),
    {
        "DESCRIPTOR": _POLYGON,
        "__module__": "raw_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.raw.Polygon)
    },
)
_sym_db.RegisterMessage(Polygon)

Path = _reflection.GeneratedProtocolMessageType(
    "Path",
    (_message.Message,),
    {
        "DESCRIPTOR": _PATH,
        "__module__": "raw_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.raw.Path)
    },
)
_sym_db.RegisterMessage(Path)

LayerShapes = _reflection.GeneratedProtocolMessageType(
    "LayerShapes",
    (_message.Message,),
    {
        "DESCRIPTOR": _LAYERSHAPES,
        "__module__": "raw_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.raw.LayerShapes)
    },
)
_sym_db.RegisterMessage(LayerShapes)

TextElement = _reflection.GeneratedProtocolMessageType(
    "TextElement",
    (_message.Message,),
    {
        "DESCRIPTOR": _TEXTELEMENT,
        "__module__": "raw_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.raw.TextElement)
    },
)
_sym_db.RegisterMessage(TextElement)

Instance = _reflection.GeneratedProtocolMessageType(
    "Instance",
    (_message.Message,),
    {
        "DESCRIPTOR": _INSTANCE,
        "__module__": "raw_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.raw.Instance)
    },
)
_sym_db.RegisterMessage(Instance)

Layout = _reflection.GeneratedProtocolMessageType(
    "Layout",
    (_message.Message,),
    {
        "DESCRIPTOR": _LAYOUT,
        "__module__": "raw_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.raw.Layout)
    },
)
_sym_db.RegisterMessage(Layout)

Abstract = _reflection.GeneratedProtocolMessageType(
    "Abstract",
    (_message.Message,),
    {
        "DESCRIPTOR": _ABSTRACT,
        "__module__": "raw_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.raw.Abstract)
    },
)
_sym_db.RegisterMessage(Abstract)

AbstractPort = _reflection.GeneratedProtocolMessageType(
    "AbstractPort",
    (_message.Message,),
    {
        "DESCRIPTOR": _ABSTRACTPORT,
        "__module__": "raw_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.raw.AbstractPort)
    },
)
_sym_db.RegisterMessage(AbstractPort)

Cell = _reflection.GeneratedProtocolMessageType(
    "Cell",
    (_message.Message,),
    {
        "DESCRIPTOR": _CELL,
        "__module__": "raw_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.raw.Cell)
    },
)
_sym_db.RegisterMessage(Cell)

Library = _reflection.GeneratedProtocolMessageType(
    "Library",
    (_message.Message,),
    {
        "DESCRIPTOR": _LIBRARY,
        "__module__": "raw_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.raw.Library)
    },
)
_sym_db.RegisterMessage(Library)

if _descriptor._USE_C_DESCRIPTORS == False:

    DESCRIPTOR._options = None
    _UNITS._serialized_start = 1424
    _UNITS._serialized_end = 1466
    _POINT._serialized_start = 52
    _POINT._serialized_end = 81
    _LAYER._serialized_start = 83
    _LAYER._serialized_end = 123
    _RECTANGLE._serialized_start = 125
    _RECTANGLE._serialized_end = 218
    _POLYGON._serialized_start = 220
    _POLYGON._serialized_end = 278
    _PATH._serialized_start = 280
    _PATH._serialized_end = 348
    _LAYERSHAPES._serialized_start = 351
    _LAYERSHAPES._serialized_end = 509
    _TEXTELEMENT._serialized_start = 511
    _TEXTELEMENT._serialized_end = 571
    _INSTANCE._serialized_start = 574
    _INSTANCE._serialized_end = 737
    _LAYOUT._serialized_start = 740
    _LAYOUT._serialized_end = 887
    _ABSTRACT._serialized_start = 890
    _ABSTRACT._serialized_end = 1034
    _ABSTRACTPORT._serialized_start = 1036
    _ABSTRACTPORT._serialized_end = 1103
    _CELL._serialized_start = 1106
    _CELL._serialized_end = 1284
    _LIBRARY._serialized_start = 1287
    _LIBRARY._serialized_end = 1422
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: geometry.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x0egeometry.proto\x12\x08vlsirlol"\x1d\n\x05Point\x12\t\n\x01x\x18\x01 \x01(\x03\x12\t\n\x01y\x18\x02 \x01(\x03"/\n\x05Layer\x12\x0e\n\x06number\x18\x01 \x01(\x03\x12\x16\n\x0e\x61nother_number\x18\x02 \x01(\x03"-\n\rQualifiedName\x12\x0e\n\x06\x64omain\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t"\\\n\tRectangle\x12\x0b\n\x03net\x18\x01 \x01(\t\x12#\n\nlower_left\x18\x02 \x01(\x0b\x32\x0f.vlsirlol.Point\x12\r\n\x05width\x18\x03 \x01(\x03\x12\x0e\n\x06height\x18\x04 \x01(\x03"9\n\x07Polygon\x12\x0b\n\x03net\x18\x01 \x01(\t\x12!\n\x08vertices\x18\x02 \x03(\x0b\x32\x0f.vlsirlol.Point"}\n\rLayeredShapes\x12\x1e\n\x05layer\x18\x01 \x01(\x0b\x32\x0f.vlsirlol.Layer\x12\'\n\nrectangles\x18\x02 \x03(\x0b\x32\x13.vlsirlol.Rectangle\x12#\n\x08polygons\x18\x03 \x03(\x0b\x32\x11.vlsirlol.Polygon"\xa0\x01\n\x04\x43\x65ll\x12%\n\x04name\x18\x01 \x01(\x0b\x32\x17.vlsirlol.QualifiedName\x12\'\n\x06shapes\x18\x02 \x03(\x0b\x32\x17.vlsirlol.LayeredShapes\x12%\n\tinstances\x18\x03 \x03(\x0b\x32\x12.vlsirlol.Instance\x12\x0e\n\x06\x61uthor\x18\x64 \x01(\t\x12\x11\n\tcopyright\x18\x65 \x01(\t"\x8d\x01\n\x08Instance\x12\x0c\n\x04name\x18\x01 \x01(\t\x12*\n\tcell_name\x18\x03 \x01(\x0b\x32\x17.vlsirlol.QualifiedName\x12"\n\x1arotation_clockwise_degrees\x18\x04 \x01(\x05\x12#\n\nlower_left\x18\x05 \x01(\x0b\x32\x0f.vlsirlol.Point"S\n\x08Geometry\x12(\n\x0ctop_instance\x18\x01 \x01(\x0b\x32\x12.vlsirlol.Instance\x12\x1d\n\x05\x63\x65lls\x18\x02 \x03(\x0b\x32\x0e.vlsirlol.Cellb\x06proto3'
)


_POINT = DESCRIPTOR.message_types_by_name["Point"]
_LAYER = DESCRIPTOR.message_types_by_name["Layer"]
_QUALIFIEDNAME = DESCRIPTOR.message_types_by_name["QualifiedName"]
_RECTANGLE = DESCRIPTOR.message_types_by_name["Rectangle"]
_POLYGON = DESCRIPTOR.message_types_by_name["Polygon"]
_LAYEREDSHAPES = DESCRIPTOR.message_types_by_name["LayeredShapes"]
_CELL = DESCRIPTOR.message_types_by_name["Cell"]
_INSTANCE = DESCRIPTOR.message_types_by_name["Instance"]
_GEOMETRY = DESCRIPTOR.message_types_by_name["Geometry"]
Point = _reflection.GeneratedProtocolMessageType(
    "Point",
    (_message.Message,),
    {
        "DESCRIPTOR": _POINT,
        "__module__": "geometry_pb2"
        # @@protoc_insertion_point(class_scope:vlsirlol.Point)
    },
)
_sym_db.RegisterMessage(Point)

Layer = _reflection.GeneratedProtocolMessageType(
    "Layer",
    (_message.Message,),
    {
        "DESCRIPTOR": _LAYER,
        "__module__": "geometry_pb2"
        # @@protoc_insertion_point(class_scope:vlsirlol.Layer)
    },
)
_sym_db.RegisterMessage(Layer)

QualifiedName = _reflection.GeneratedProtocolMessageType(
    "QualifiedName",
    (_message.Message,),
    {
        "DESCRIPTOR": _QUALIFIEDNAME,
        "__module__": "geometry_pb2"
        # @@protoc_insertion_point(class_scope:vlsirlol.QualifiedName)
    },
)
_sym_db.RegisterMessage(QualifiedName)

Rectangle = _reflection.GeneratedProtocolMessageType(
    "Rectangle",
    (_message.Message,),
    {
        "DESCRIPTOR": _RECTANGLE,
        "__module__": "geometry_pb2"
        # @@protoc_insertion_point(class_scope:vlsirlol.Rectangle)
    },
)
_sym_db.RegisterMessage(Rectangle)

Polygon = _reflection.GeneratedProtocolMessageType(
    "Polygon",
    (_message.Message,),
    {
        "DESCRIPTOR": _POLYGON,
        "__module__": "geometry_pb2"
        # @@protoc_insertion_point(class_scope:vlsirlol.Polygon)
    },
)
_sym_db.RegisterMessage(Polygon)

LayeredShapes = _reflection.GeneratedProtocolMessageType(
    "LayeredShapes",
    (_message.Message,),
    {
        "DESCRIPTOR": _LAYEREDSHAPES,
        "__module__": "geometry_pb2"
        # @@protoc_insertion_point(class_scope:vlsirlol.LayeredShapes)
    },
)
_sym_db.RegisterMessage(LayeredShapes)

Cell = _reflection.GeneratedProtocolMessageType(
    "Cell",
    (_message.Message,),
    {
        "DESCRIPTOR": _CELL,
        "__module__": "geometry_pb2"
        # @@protoc_insertion_point(class_scope:vlsirlol.Cell)
    },
)
_sym_db.RegisterMessage(Cell)

Instance = _reflection.GeneratedProtocolMessageType(
    "Instance",
    (_message.Message,),
    {
        "DESCRIPTOR": _INSTANCE,
        "__module__": "geometry_pb2"
        # @@protoc_insertion_point(class_scope:vlsirlol.Instance)
    },
)
_sym_db.RegisterMessage(Instance)

Geometry = _reflection.GeneratedProtocolMessageType(
    "Geometry",
    (_message.Message,),
    {
        "DESCRIPTOR": _GEOMETRY,
        "__module__": "geometry_pb2"
        # @@protoc_insertion_point(class_scope:vlsirlol.Geometry)
    },
)
_sym_db.RegisterMessage(Geometry)

if _descriptor._USE_C_DESCRIPTORS == False:

    DESCRIPTOR._options = None
    _POINT._serialized_start = 28
    _POINT._serialized_end = 57
    _LAYER._serialized_start = 59
    _LAYER._serialized_end = 106
    _QUALIFIEDNAME._serialized_start = 108
    _QUALIFIEDNAME._serialized_end = 153
    _RECTANGLE._serialized_start = 155
    _RECTANGLE._serialized_end = 247
    _POLYGON._serialized_start = 249
    _POLYGON._serialized_end = 306
    _LAYEREDSHAPES._serialized_start = 308
    _LAYEREDSHAPES._serialized_end = 433
    _CELL._serialized_start = 436
    _CELL._serialized_end = 596
    _INSTANCE._serialized_start = 599
    _INSTANCE._serialized_end = 740
    _GEOMETRY._serialized_start = 742
    _GEOMETRY._serialized_end = 825
# @@protoc_insertion_point(module_scope)



""" 
# Primitive Definitions 

Loaded from adjacent file `vlsir.primitives.pb.txt`
"""

import sys
from pathlib import Path
from .circuit_pb2 import Package

# Get the definition-file from this file's directory
here = Path(__file__).parent.absolute()
prims = here / "vlsir.primitives.pb.txt"

# And parse it into a `circuit.Package`
from google.protobuf import text_format

pkg = Package()
text_format.Parse(open(prims, "r").read(), pkg)

# Also make each `ExternalModule` available in
# (a) A {name: ExternalModule} dictionary, and
# (b) This namespace, under its module-name.
dct = dict()
for emod in pkg.ext_modules:
    # First make sure the module-name is valid, and not already defined.
    modname = emod.name.name
    if "." in modname:
        raise RuntimeError(f"Invalid module-name: {emod.name}")
    if getattr(sys.modules[__name__], modname, None) is not None:
        raise RuntimeError(f"Module-name conflict: {modname}")

    # Checks out: add it
    setattr(sys.modules[__name__], modname, emod)
    dct[modname] = emod



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: utils.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x0butils.proto\x12\x0bvlsir.utils"r\n\x08Prefixed\x12%\n\x06prefix\x18\x01 \x01(\x0e\x32\x15.vlsir.utils.SIPrefix\x12\x11\n\x07integer\x18\x02 \x01(\x03H\x00\x12\x10\n\x06\x64ouble\x18\x03 \x01(\x01H\x00\x12\x10\n\x06string\x18\x04 \x01(\tH\x00\x42\x08\n\x06number"\x8a\x01\n\nParamValue\x12\x11\n\x07integer\x18\x02 \x01(\x03H\x00\x12\x10\n\x06\x64ouble\x18\x03 \x01(\x01H\x00\x12\x10\n\x06string\x18\x04 \x01(\tH\x00\x12\x11\n\x07literal\x18\x05 \x01(\tH\x00\x12)\n\x08prefixed\x18\x06 \x01(\x0b\x32\x15.vlsir.utils.PrefixedH\x00\x42\x07\n\x05value"K\n\x05Param\x12\x0c\n\x04name\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.vlsir.utils.ParamValue\x12\x0c\n\x04\x64\x65sc\x18\x03 \x01(\t"-\n\rQualifiedName\x12\x0e\n\x06\x64omain\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t"R\n\tReference\x12\x0f\n\x05local\x18\x01 \x01(\tH\x00\x12.\n\x08\x65xternal\x18\x02 \x01(\x0b\x32\x1a.vlsir.utils.QualifiedNameH\x00\x42\x04\n\x02to"b\n\x0fLibraryMetadata\x12\x0e\n\x06\x64omain\x18\x01 \x01(\t\x12\x12\n\ncell_names\x18\n \x03(\t\x12+\n\x06\x61uthor\x18\x14 \x01(\x0b\x32\x1b.vlsir.utils.AuthorMetadata"D\n\x0e\x41uthorMetadata\x12\x0e\n\x06\x61uthor\x18\x01 \x01(\t\x12\x11\n\tcopyright\x18\n \x01(\t\x12\x0f\n\x07license\x18\x0b \x01(\t*\xe4\x01\n\x08SIPrefix\x12\t\n\x05YOCTO\x10\x00\x12\t\n\x05ZEPTO\x10\x01\x12\x08\n\x04\x41TTO\x10\x02\x12\t\n\x05\x46\x45MTO\x10\x03\x12\x08\n\x04PICO\x10\x04\x12\x08\n\x04NANO\x10\x05\x12\t\n\x05MICRO\x10\x06\x12\t\n\x05MILLI\x10\x07\x12\t\n\x05\x43\x45NTI\x10\x08\x12\x08\n\x04\x44\x45\x43I\x10\t\x12\x08\n\x04\x44\x45\x43\x41\x10\n\x12\t\n\x05HECTO\x10\x0b\x12\x08\n\x04KILO\x10\x0c\x12\x08\n\x04MEGA\x10\r\x12\x08\n\x04GIGA\x10\x0e\x12\x08\n\x04TERA\x10\x0f\x12\x08\n\x04PETA\x10\x10\x12\x07\n\x03\x45XA\x10\x11\x12\t\n\x05ZETTA\x10\x12\x12\t\n\x05YOTTA\x10\x13\x12\x08\n\x04UNIT\x10\x14\x62\x06proto3'
)

_SIPREFIX = DESCRIPTOR.enum_types_by_name["SIPrefix"]
SIPrefix = enum_type_wrapper.EnumTypeWrapper(_SIPREFIX)
YOCTO = 0
ZEPTO = 1
ATTO = 2
FEMTO = 3
PICO = 4
NANO = 5
MICRO = 6
MILLI = 7
CENTI = 8
DECI = 9
DECA = 10
HECTO = 11
KILO = 12
MEGA = 13
GIGA = 14
TERA = 15
PETA = 16
EXA = 17
ZETTA = 18
YOTTA = 19
UNIT = 20


_PREFIXED = DESCRIPTOR.message_types_by_name["Prefixed"]
_PARAMVALUE = DESCRIPTOR.message_types_by_name["ParamValue"]
_PARAM = DESCRIPTOR.message_types_by_name["Param"]
_QUALIFIEDNAME = DESCRIPTOR.message_types_by_name["QualifiedName"]
_REFERENCE = DESCRIPTOR.message_types_by_name["Reference"]
_LIBRARYMETADATA = DESCRIPTOR.message_types_by_name["LibraryMetadata"]
_AUTHORMETADATA = DESCRIPTOR.message_types_by_name["AuthorMetadata"]
Prefixed = _reflection.GeneratedProtocolMessageType(
    "Prefixed",
    (_message.Message,),
    {
        "DESCRIPTOR": _PREFIXED,
        "__module__": "utils_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.utils.Prefixed)
    },
)
_sym_db.RegisterMessage(Prefixed)

ParamValue = _reflection.GeneratedProtocolMessageType(
    "ParamValue",
    (_message.Message,),
    {
        "DESCRIPTOR": _PARAMVALUE,
        "__module__": "utils_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.utils.ParamValue)
    },
)
_sym_db.RegisterMessage(ParamValue)

Param = _reflection.GeneratedProtocolMessageType(
    "Param",
    (_message.Message,),
    {
        "DESCRIPTOR": _PARAM,
        "__module__": "utils_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.utils.Param)
    },
)
_sym_db.RegisterMessage(Param)

QualifiedName = _reflection.GeneratedProtocolMessageType(
    "QualifiedName",
    (_message.Message,),
    {
        "DESCRIPTOR": _QUALIFIEDNAME,
        "__module__": "utils_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.utils.QualifiedName)
    },
)
_sym_db.RegisterMessage(QualifiedName)

Reference = _reflection.GeneratedProtocolMessageType(
    "Reference",
    (_message.Message,),
    {
        "DESCRIPTOR": _REFERENCE,
        "__module__": "utils_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.utils.Reference)
    },
)
_sym_db.RegisterMessage(Reference)

LibraryMetadata = _reflection.GeneratedProtocolMessageType(
    "LibraryMetadata",
    (_message.Message,),
    {
        "DESCRIPTOR": _LIBRARYMETADATA,
        "__module__": "utils_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.utils.LibraryMetadata)
    },
)
_sym_db.RegisterMessage(LibraryMetadata)

AuthorMetadata = _reflection.GeneratedProtocolMessageType(
    "AuthorMetadata",
    (_message.Message,),
    {
        "DESCRIPTOR": _AUTHORMETADATA,
        "__module__": "utils_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.utils.AuthorMetadata)
    },
)
_sym_db.RegisterMessage(AuthorMetadata)

if _descriptor._USE_C_DESCRIPTORS == False:

    DESCRIPTOR._options = None
    _SIPREFIX._serialized_start = 664
    _SIPREFIX._serialized_end = 892
    _PREFIXED._serialized_start = 28
    _PREFIXED._serialized_end = 142
    _PARAMVALUE._serialized_start = 145
    _PARAMVALUE._serialized_end = 283
    _PARAM._serialized_start = 285
    _PARAM._serialized_end = 360
    _QUALIFIEDNAME._serialized_start = 362
    _QUALIFIEDNAME._serialized_end = 407
    _REFERENCE._serialized_start = 409
    _REFERENCE._serialized_end = 491
    _LIBRARYMETADATA._serialized_start = 493
    _LIBRARYMETADATA._serialized_end = 591
    _AUTHORMETADATA._serialized_start = 593
    _AUTHORMETADATA._serialized_end = 661
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spice.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import utils_pb2 as utils__pb2
from . import circuit_pb2 as circuit__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x0bspice.proto\x12\x0bvlsir.spice\x1a\x0butils.proto\x1a\rcircuit.proto"\xab\x01\n\x08SimInput\x12#\n\x03pkg\x18\x01 \x01(\x0b\x32\x16.vlsir.circuit.Package\x12\x0b\n\x03top\x18\x02 \x01(\t\x12%\n\x04opts\x18\n \x03(\x0b\x32\x17.vlsir.spice.SimOptions\x12!\n\x02\x61n\x18\x0b \x03(\x0b\x32\x15.vlsir.spice.Analysis\x12#\n\x05\x63trls\x18\x0c \x03(\x0b\x32\x14.vlsir.spice.Control"4\n\tSimResult\x12\'\n\x02\x61n\x18\x01 \x03(\x0b\x32\x1b.vlsir.spice.AnalysisResult"W\n\nSimOptions\x12\x0c\n\x04temp\x18\x01 \x01(\x01\x12\x0c\n\x04tnom\x18\x02 \x01(\x01\x12\x0c\n\x04gmin\x18\x03 \x01(\x01\x12\x0f\n\x07iabstol\x18\x04 \x01(\x01\x12\x0e\n\x06reltol\x18\x05 \x01(\x01"\xd6\x02\n\x08\x41nalysis\x12"\n\x02op\x18\x01 \x01(\x0b\x32\x14.vlsir.spice.OpInputH\x00\x12"\n\x02\x64\x63\x18\x02 \x01(\x0b\x32\x14.vlsir.spice.DcInputH\x00\x12&\n\x04tran\x18\x03 \x01(\x0b\x32\x16.vlsir.spice.TranInputH\x00\x12"\n\x02\x61\x63\x18\x04 \x01(\x0b\x32\x14.vlsir.spice.AcInputH\x00\x12(\n\x05noise\x18\x05 \x01(\x0b\x32\x17.vlsir.spice.NoiseInputH\x00\x12(\n\x05sweep\x18\n \x01(\x0b\x32\x17.vlsir.spice.SweepInputH\x00\x12(\n\x05monte\x18\x0b \x01(\x0b\x32\x17.vlsir.spice.MonteInputH\x00\x12\x32\n\x06\x63ustom\x18\x14 \x01(\x0b\x32 .vlsir.spice.CustomAnalysisInputH\x00\x42\x04\n\x02\x61n"\xe4\x02\n\x0e\x41nalysisResult\x12#\n\x02op\x18\x01 \x01(\x0b\x32\x15.vlsir.spice.OpResultH\x00\x12#\n\x02\x64\x63\x18\x02 \x01(\x0b\x32\x15.vlsir.spice.DcResultH\x00\x12\'\n\x04tran\x18\x03 \x01(\x0b\x32\x17.vlsir.spice.TranResultH\x00\x12#\n\x02\x61\x63\x18\x04 \x01(\x0b\x32\x15.vlsir.spice.AcResultH\x00\x12)\n\x05noise\x18\x05 \x01(\x0b\x32\x18.vlsir.spice.NoiseResultH\x00\x12)\n\x05sweep\x18\n \x01(\x0b\x32\x18.vlsir.spice.SweepResultH\x00\x12)\n\x05monte\x18\x0b \x01(\x0b\x32\x18.vlsir.spice.MonteResultH\x00\x12\x33\n\x06\x63ustom\x18\x14 \x01(\x0b\x32!.vlsir.spice.CustomAnalysisResultH\x00\x42\x04\n\x02\x61n"E\n\x07OpInput\x12\x15\n\ranalysis_name\x18\x01 \x01(\t\x12#\n\x05\x63trls\x18\x05 \x03(\x0b\x32\x14.vlsir.spice.Control"L\n\x08OpResult\x12\x15\n\ranalysis_name\x18\x01 \x01(\t\x12\x0f\n\x07signals\x18\x03 \x03(\t\x12\x0c\n\x04\x64\x61ta\x18\x05 \x03(\x01J\x04\x08\x02\x10\x03J\x04\x08\x04\x10\x05"|\n\x07\x44\x63Input\x12\x15\n\ranalysis_name\x18\x01 \x01(\t\x12\x12\n\nindep_name\x18\x02 \x01(\t\x12!\n\x05sweep\x18\x03 \x01(\x0b\x32\x12.vlsir.spice.Sweep\x12#\n\x05\x63trls\x18\x05 \x03(\x0b\x32\x14.vlsir.spice.Control"\xce\x01\n\x08\x44\x63Result\x12\x15\n\ranalysis_name\x18\x01 \x01(\t\x12\x12\n\nindep_name\x18\x02 \x01(\t\x12\x0f\n\x07signals\x18\x03 \x03(\t\x12\x0c\n\x04\x64\x61ta\x18\x05 \x03(\x01\x12=\n\x0cmeasurements\x18\n \x03(\x0b\x32\'.vlsir.spice.DcResult.MeasurementsEntry\x1a\x33\n\x11MeasurementsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01J\x04\x08\x04\x10\x05"\xbc\x01\n\tTranInput\x12\x15\n\ranalysis_name\x18\x01 \x01(\t\x12\r\n\x05tstop\x18\x02 \x01(\x01\x12\r\n\x05tstep\x18\x03 \x01(\x01\x12*\n\x02ic\x18\x04 \x03(\x0b\x32\x1e.vlsir.spice.TranInput.IcEntry\x12#\n\x05\x63trls\x18\x05 \x03(\x0b\x32\x14.vlsir.spice.Control\x1a)\n\x07IcEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01"\xc4\x01\n\nTranResult\x12\x15\n\ranalysis_name\x18\x01 \x01(\t\x12\x0f\n\x07signals\x18\x03 \x03(\t\x12\x0c\n\x04\x64\x61ta\x18\x05 \x03(\x01\x12?\n\x0cmeasurements\x18\n \x03(\x0b\x32).vlsir.spice.TranResult.MeasurementsEntry\x1a\x33\n\x11MeasurementsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01J\x04\x08\x02\x10\x03J\x04\x08\x04\x10\x05"$\n\nComplexNum\x12\n\n\x02re\x18\x01 \x01(\x01\x12\n\n\x02im\x18\x02 \x01(\x01"r\n\x07\x41\x63Input\x12\x15\n\ranalysis_name\x18\x01 \x01(\t\x12\x0e\n\x06\x66start\x18\x02 \x01(\x01\x12\r\n\x05\x66stop\x18\x03 \x01(\x01\x12\x0c\n\x04npts\x18\x04 \x01(\x04\x12#\n\x05\x63trls\x18\x05 \x03(\x0b\x32\x14.vlsir.spice.Control"\xe1\x01\n\x08\x41\x63Result\x12\x15\n\ranalysis_name\x18\x01 \x01(\t\x12\x0c\n\x04\x66req\x18\x02 \x03(\x01\x12\x0f\n\x07signals\x18\x03 \x03(\t\x12%\n\x04\x64\x61ta\x18\x05 \x03(\x0b\x32\x17.vlsir.spice.ComplexNum\x12=\n\x0cmeasurements\x18\n \x03(\x0b\x32\'.vlsir.spice.AcResult.MeasurementsEntry\x1a\x33\n\x11MeasurementsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01J\x04\x08\x04\x10\x05"\xaf\x01\n\nNoiseInput\x12\x15\n\ranalysis_name\x18\x01 \x01(\t\x12\x10\n\x08output_p\x18\x02 \x01(\t\x12\x10\n\x08output_n\x18\x03 \x01(\t\x12\x14\n\x0cinput_source\x18\x04 \x01(\t\x12\x0e\n\x06\x66start\x18\n \x01(\x01\x12\r\n\x05\x66stop\x18\x0b \x01(\x01\x12\x0c\n\x04npts\x18\x0c \x01(\x04\x12#\n\x05\x63trls\x18\x14 \x03(\x0b\x32\x14.vlsir.spice.Control"\xc7\x02\n\x0bNoiseResult\x12\x15\n\ranalysis_name\x18\x01 \x01(\t\x12\x0f\n\x07signals\x18\x03 \x03(\t\x12\x0c\n\x04\x64\x61ta\x18\x05 \x03(\x01\x12G\n\x10integrated_noise\x18\n \x03(\x0b\x32-.vlsir.spice.NoiseResult.IntegratedNoiseEntry\x12@\n\x0cmeasurements\x18\x0b \x03(\x0b\x32*.vlsir.spice.NoiseResult.MeasurementsEntry\x1a\x36\n\x14IntegratedNoiseEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01\x1a\x33\n\x11MeasurementsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01J\x04\x08\x02\x10\x03J\x04\x08\x04\x10\x05"\xa0\x01\n\nSweepInput\x12\x15\n\ranalysis_name\x18\x01 \x01(\t\x12\x10\n\x08variable\x18\x02 \x01(\t\x12!\n\x05sweep\x18\x03 \x01(\x0b\x32\x12.vlsir.spice.Sweep\x12!\n\x02\x61n\x18\x04 \x03(\x0b\x32\x15.vlsir.spice.Analysis\x12#\n\x05\x63trls\x18\x05 \x03(\x0b\x32\x14.vlsir.spice.Control"\x82\x01\n\x0bSweepResult\x12\x15\n\ranalysis_name\x18\x01 \x01(\t\x12\x10\n\x08variable\x18\x02 \x01(\t\x12!\n\x05sweep\x18\x03 \x01(\x0b\x32\x12.vlsir.spice.Sweep\x12\'\n\x02\x61n\x18\x04 \x03(\x0b\x32\x1b.vlsir.spice.AnalysisResult"\x87\x01\n\nMonteInput\x12\x15\n\ranalysis_name\x18\x01 \x01(\t\x12\x0c\n\x04npts\x18\x02 \x01(\x03\x12\x0c\n\x04seed\x18\x03 \x01(\x03\x12!\n\x02\x61n\x18\x04 \x03(\x0b\x32\x15.vlsir.spice.Analysis\x12#\n\x05\x63trls\x18\x05 \x03(\x0b\x32\x14.vlsir.spice.Control"\x82\x01\n\x0bMonteResult\x12\x15\n\ranalysis_name\x18\x01 \x01(\t\x12\x10\n\x08variable\x18\x02 \x01(\t\x12!\n\x05sweep\x18\x03 \x01(\x0b\x32\x12.vlsir.spice.Sweep\x12\'\n\x02\x61n\x18\x04 \x03(\x0b\x32\x1b.vlsir.spice.AnalysisResult"^\n\x13\x43ustomAnalysisInput\x12\x15\n\ranalysis_name\x18\x01 \x01(\t\x12\x0b\n\x03\x63md\x18\x02 \x01(\t\x12#\n\x05\x63trls\x18\x05 \x03(\x0b\x32\x14.vlsir.spice.Control"\x16\n\x14\x43ustomAnalysisResult"\x8a\x01\n\x05Sweep\x12*\n\x06linear\x18\x01 \x01(\x0b\x32\x18.vlsir.spice.LinearSweepH\x00\x12$\n\x03log\x18\x02 \x01(\x0b\x32\x15.vlsir.spice.LogSweepH\x00\x12)\n\x06points\x18\x03 \x01(\x0b\x32\x17.vlsir.spice.PointSweepH\x00\x42\x04\n\x02tp"8\n\x0bLinearSweep\x12\r\n\x05start\x18\x01 \x01(\x01\x12\x0c\n\x04stop\x18\x02 \x01(\x01\x12\x0c\n\x04step\x18\x03 \x01(\x01"5\n\x08LogSweep\x12\r\n\x05start\x18\x01 \x01(\x01\x12\x0c\n\x04stop\x18\x02 \x01(\x01\x12\x0c\n\x04npts\x18\x03 \x01(\x01"8\n\nPointSweep\x12\x0e\n\x06points\x18\x01 \x03(\x01\x12\x0c\n\x04stop\x18\x02 \x01(\x01\x12\x0c\n\x04npts\x18\x03 \x01(\x01"\xe0\x01\n\x07\x43ontrol\x12\'\n\x07include\x18\x01 \x01(\x0b\x32\x14.vlsir.spice.IncludeH\x00\x12&\n\x03lib\x18\x02 \x01(\x0b\x32\x17.vlsir.spice.LibIncludeH\x00\x12!\n\x04save\x18\x05 \x01(\x0b\x32\x11.vlsir.spice.SaveH\x00\x12!\n\x04meas\x18\x06 \x01(\x0b\x32\x11.vlsir.spice.MeasH\x00\x12#\n\x05param\x18\x07 \x01(\x0b\x32\x12.vlsir.utils.ParamH\x00\x12\x11\n\x07literal\x18\n \x01(\tH\x00\x42\x06\n\x04\x63trl"k\n\x04Save\x12*\n\x04mode\x18\x01 \x01(\x0e\x32\x1a.vlsir.spice.Save.SaveModeH\x00\x12\x10\n\x06signal\x18\x02 \x01(\tH\x00"\x1d\n\x08SaveMode\x12\x08\n\x04NONE\x10\x00\x12\x07\n\x03\x41LL\x10\x01\x42\x06\n\x04save"\x17\n\x07Include\x12\x0c\n\x04path\x18\x01 \x01(\t"+\n\nLibInclude\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0f\n\x07section\x18\x02 \x01(\t"9\n\x04Meas\x12\x15\n\ranalysis_type\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x65xpr\x18\x03 \x01(\t"v\n\x06Signal\x12\x0c\n\x04name\x18\x01 \x01(\t\x12.\n\x08quantity\x18\x02 \x01(\x0e\x32\x1c.vlsir.spice.Signal.Quantity".\n\x08Quantity\x12\x0b\n\x07VOLTAGE\x10\x00\x12\x0b\n\x07\x43URRENT\x10\x01\x12\x08\n\x04NONE\x10\x03\x32=\n\x05Spice\x12\x34\n\x03Sim\x12\x15.vlsir.spice.SimInput\x1a\x16.vlsir.spice.SimResultb\x06proto3'
)


_SIMINPUT = DESCRIPTOR.message_types_by_name["SimInput"]
_SIMRESULT = DESCRIPTOR.message_types_by_name["SimResult"]
_SIMOPTIONS = DESCRIPTOR.message_types_by_name["SimOptions"]
_ANALYSIS = DESCRIPTOR.message_types_by_name["Analysis"]
_ANALYSISRESULT = DESCRIPTOR.message_types_by_name["AnalysisResult"]
_OPINPUT = DESCRIPTOR.message_types_by_name["OpInput"]
_OPRESULT = DESCRIPTOR.message_types_by_name["OpResult"]
_DCINPUT = DESCRIPTOR.message_types_by_name["DcInput"]
_DCRESULT = DESCRIPTOR.message_types_by_name["DcResult"]
_DCRESULT_MEASUREMENTSENTRY = _DCRESULT.nested_types_by_name["MeasurementsEntry"]
_TRANINPUT = DESCRIPTOR.message_types_by_name["TranInput"]
_TRANINPUT_ICENTRY = _TRANINPUT.nested_types_by_name["IcEntry"]
_TRANRESULT = DESCRIPTOR.message_types_by_name["TranResult"]
_TRANRESULT_MEASUREMENTSENTRY = _TRANRESULT.nested_types_by_name["MeasurementsEntry"]
_COMPLEXNUM = DESCRIPTOR.message_types_by_name["ComplexNum"]
_ACINPUT = DESCRIPTOR.message_types_by_name["AcInput"]
_ACRESULT = DESCRIPTOR.message_types_by_name["AcResult"]
_ACRESULT_MEASUREMENTSENTRY = _ACRESULT.nested_types_by_name["MeasurementsEntry"]
_NOISEINPUT = DESCRIPTOR.message_types_by_name["NoiseInput"]
_NOISERESULT = DESCRIPTOR.message_types_by_name["NoiseResult"]
_NOISERESULT_INTEGRATEDNOISEENTRY = _NOISERESULT.nested_types_by_name[
    "IntegratedNoiseEntry"
]
_NOISERESULT_MEASUREMENTSENTRY = _NOISERESULT.nested_types_by_name["MeasurementsEntry"]
_SWEEPINPUT = DESCRIPTOR.message_types_by_name["SweepInput"]
_SWEEPRESULT = DESCRIPTOR.message_types_by_name["SweepResult"]
_MONTEINPUT = DESCRIPTOR.message_types_by_name["MonteInput"]
_MONTERESULT = DESCRIPTOR.message_types_by_name["MonteResult"]
_CUSTOMANALYSISINPUT = DESCRIPTOR.message_types_by_name["CustomAnalysisInput"]
_CUSTOMANALYSISRESULT = DESCRIPTOR.message_types_by_name["CustomAnalysisResult"]
_SWEEP = DESCRIPTOR.message_types_by_name["Sweep"]
_LINEARSWEEP = DESCRIPTOR.message_types_by_name["LinearSweep"]
_LOGSWEEP = DESCRIPTOR.message_types_by_name["LogSweep"]
_POINTSWEEP = DESCRIPTOR.message_types_by_name["PointSweep"]
_CONTROL = DESCRIPTOR.message_types_by_name["Control"]
_SAVE = DESCRIPTOR.message_types_by_name["Save"]
_INCLUDE = DESCRIPTOR.message_types_by_name["Include"]
_LIBINCLUDE = DESCRIPTOR.message_types_by_name["LibInclude"]
_MEAS = DESCRIPTOR.message_types_by_name["Meas"]
_SIGNAL = DESCRIPTOR.message_types_by_name["Signal"]
_SAVE_SAVEMODE = _SAVE.enum_types_by_name["SaveMode"]
_SIGNAL_QUANTITY = _SIGNAL.enum_types_by_name["Quantity"]
SimInput = _reflection.GeneratedProtocolMessageType(
    "SimInput",
    (_message.Message,),
    {
        "DESCRIPTOR": _SIMINPUT,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.SimInput)
    },
)
_sym_db.RegisterMessage(SimInput)

SimResult = _reflection.GeneratedProtocolMessageType(
    "SimResult",
    (_message.Message,),
    {
        "DESCRIPTOR": _SIMRESULT,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.SimResult)
    },
)
_sym_db.RegisterMessage(SimResult)

SimOptions = _reflection.GeneratedProtocolMessageType(
    "SimOptions",
    (_message.Message,),
    {
        "DESCRIPTOR": _SIMOPTIONS,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.SimOptions)
    },
)
_sym_db.RegisterMessage(SimOptions)

Analysis = _reflection.GeneratedProtocolMessageType(
    "Analysis",
    (_message.Message,),
    {
        "DESCRIPTOR": _ANALYSIS,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.Analysis)
    },
)
_sym_db.RegisterMessage(Analysis)

AnalysisResult = _reflection.GeneratedProtocolMessageType(
    "AnalysisResult",
    (_message.Message,),
    {
        "DESCRIPTOR": _ANALYSISRESULT,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.AnalysisResult)
    },
)
_sym_db.RegisterMessage(AnalysisResult)

OpInput = _reflection.GeneratedProtocolMessageType(
    "OpInput",
    (_message.Message,),
    {
        "DESCRIPTOR": _OPINPUT,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.OpInput)
    },
)
_sym_db.RegisterMessage(OpInput)

OpResult = _reflection.GeneratedProtocolMessageType(
    "OpResult",
    (_message.Message,),
    {
        "DESCRIPTOR": _OPRESULT,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.OpResult)
    },
)
_sym_db.RegisterMessage(OpResult)

DcInput = _reflection.GeneratedProtocolMessageType(
    "DcInput",
    (_message.Message,),
    {
        "DESCRIPTOR": _DCINPUT,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.DcInput)
    },
)
_sym_db.RegisterMessage(DcInput)

DcResult = _reflection.GeneratedProtocolMessageType(
    "DcResult",
    (_message.Message,),
    {
        "MeasurementsEntry": _reflection.GeneratedProtocolMessageType(
            "MeasurementsEntry",
            (_message.Message,),
            {
                "DESCRIPTOR": _DCRESULT_MEASUREMENTSENTRY,
                "__module__": "spice_pb2"
                # @@protoc_insertion_point(class_scope:vlsir.spice.DcResult.MeasurementsEntry)
            },
        ),
        "DESCRIPTOR": _DCRESULT,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.DcResult)
    },
)
_sym_db.RegisterMessage(DcResult)
_sym_db.RegisterMessage(DcResult.MeasurementsEntry)

TranInput = _reflection.GeneratedProtocolMessageType(
    "TranInput",
    (_message.Message,),
    {
        "IcEntry": _reflection.GeneratedProtocolMessageType(
            "IcEntry",
            (_message.Message,),
            {
                "DESCRIPTOR": _TRANINPUT_ICENTRY,
                "__module__": "spice_pb2"
                # @@protoc_insertion_point(class_scope:vlsir.spice.TranInput.IcEntry)
            },
        ),
        "DESCRIPTOR": _TRANINPUT,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.TranInput)
    },
)
_sym_db.RegisterMessage(TranInput)
_sym_db.RegisterMessage(TranInput.IcEntry)

TranResult = _reflection.GeneratedProtocolMessageType(
    "TranResult",
    (_message.Message,),
    {
        "MeasurementsEntry": _reflection.GeneratedProtocolMessageType(
            "MeasurementsEntry",
            (_message.Message,),
            {
                "DESCRIPTOR": _TRANRESULT_MEASUREMENTSENTRY,
                "__module__": "spice_pb2"
                # @@protoc_insertion_point(class_scope:vlsir.spice.TranResult.MeasurementsEntry)
            },
        ),
        "DESCRIPTOR": _TRANRESULT,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.TranResult)
    },
)
_sym_db.RegisterMessage(TranResult)
_sym_db.RegisterMessage(TranResult.MeasurementsEntry)

ComplexNum = _reflection.GeneratedProtocolMessageType(
    "ComplexNum",
    (_message.Message,),
    {
        "DESCRIPTOR": _COMPLEXNUM,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.ComplexNum)
    },
)
_sym_db.RegisterMessage(ComplexNum)

AcInput = _reflection.GeneratedProtocolMessageType(
    "AcInput",
    (_message.Message,),
    {
        "DESCRIPTOR": _ACINPUT,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.AcInput)
    },
)
_sym_db.RegisterMessage(AcInput)

AcResult = _reflection.GeneratedProtocolMessageType(
    "AcResult",
    (_message.Message,),
    {
        "MeasurementsEntry": _reflection.GeneratedProtocolMessageType(
            "MeasurementsEntry",
            (_message.Message,),
            {
                "DESCRIPTOR": _ACRESULT_MEASUREMENTSENTRY,
                "__module__": "spice_pb2"
                # @@protoc_insertion_point(class_scope:vlsir.spice.AcResult.MeasurementsEntry)
            },
        ),
        "DESCRIPTOR": _ACRESULT,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.AcResult)
    },
)
_sym_db.RegisterMessage(AcResult)
_sym_db.RegisterMessage(AcResult.MeasurementsEntry)

NoiseInput = _reflection.GeneratedProtocolMessageType(
    "NoiseInput",
    (_message.Message,),
    {
        "DESCRIPTOR": _NOISEINPUT,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.NoiseInput)
    },
)
_sym_db.RegisterMessage(NoiseInput)

NoiseResult = _reflection.GeneratedProtocolMessageType(
    "NoiseResult",
    (_message.Message,),
    {
        "IntegratedNoiseEntry": _reflection.GeneratedProtocolMessageType(
            "IntegratedNoiseEntry",
            (_message.Message,),
            {
                "DESCRIPTOR": _NOISERESULT_INTEGRATEDNOISEENTRY,
                "__module__": "spice_pb2"
                # @@protoc_insertion_point(class_scope:vlsir.spice.NoiseResult.IntegratedNoiseEntry)
            },
        ),
        "MeasurementsEntry": _reflection.GeneratedProtocolMessageType(
            "MeasurementsEntry",
            (_message.Message,),
            {
                "DESCRIPTOR": _NOISERESULT_MEASUREMENTSENTRY,
                "__module__": "spice_pb2"
                # @@protoc_insertion_point(class_scope:vlsir.spice.NoiseResult.MeasurementsEntry)
            },
        ),
        "DESCRIPTOR": _NOISERESULT,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.NoiseResult)
    },
)
_sym_db.RegisterMessage(NoiseResult)
_sym_db.RegisterMessage(NoiseResult.IntegratedNoiseEntry)
_sym_db.RegisterMessage(NoiseResult.MeasurementsEntry)

SweepInput = _reflection.GeneratedProtocolMessageType(
    "SweepInput",
    (_message.Message,),
    {
        "DESCRIPTOR": _SWEEPINPUT,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.SweepInput)
    },
)
_sym_db.RegisterMessage(SweepInput)

SweepResult = _reflection.GeneratedProtocolMessageType(
    "SweepResult",
    (_message.Message,),
    {
        "DESCRIPTOR": _SWEEPRESULT,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.SweepResult)
    },
)
_sym_db.RegisterMessage(SweepResult)

MonteInput = _reflection.GeneratedProtocolMessageType(
    "MonteInput",
    (_message.Message,),
    {
        "DESCRIPTOR": _MONTEINPUT,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.MonteInput)
    },
)
_sym_db.RegisterMessage(MonteInput)

MonteResult = _reflection.GeneratedProtocolMessageType(
    "MonteResult",
    (_message.Message,),
    {
        "DESCRIPTOR": _MONTERESULT,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.MonteResult)
    },
)
_sym_db.RegisterMessage(MonteResult)

CustomAnalysisInput = _reflection.GeneratedProtocolMessageType(
    "CustomAnalysisInput",
    (_message.Message,),
    {
        "DESCRIPTOR": _CUSTOMANALYSISINPUT,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.CustomAnalysisInput)
    },
)
_sym_db.RegisterMessage(CustomAnalysisInput)

CustomAnalysisResult = _reflection.GeneratedProtocolMessageType(
    "CustomAnalysisResult",
    (_message.Message,),
    {
        "DESCRIPTOR": _CUSTOMANALYSISRESULT,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.CustomAnalysisResult)
    },
)
_sym_db.RegisterMessage(CustomAnalysisResult)

Sweep = _reflection.GeneratedProtocolMessageType(
    "Sweep",
    (_message.Message,),
    {
        "DESCRIPTOR": _SWEEP,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.Sweep)
    },
)
_sym_db.RegisterMessage(Sweep)

LinearSweep = _reflection.GeneratedProtocolMessageType(
    "LinearSweep",
    (_message.Message,),
    {
        "DESCRIPTOR": _LINEARSWEEP,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.LinearSweep)
    },
)
_sym_db.RegisterMessage(LinearSweep)

LogSweep = _reflection.GeneratedProtocolMessageType(
    "LogSweep",
    (_message.Message,),
    {
        "DESCRIPTOR": _LOGSWEEP,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.LogSweep)
    },
)
_sym_db.RegisterMessage(LogSweep)

PointSweep = _reflection.GeneratedProtocolMessageType(
    "PointSweep",
    (_message.Message,),
    {
        "DESCRIPTOR": _POINTSWEEP,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.PointSweep)
    },
)
_sym_db.RegisterMessage(PointSweep)

Control = _reflection.GeneratedProtocolMessageType(
    "Control",
    (_message.Message,),
    {
        "DESCRIPTOR": _CONTROL,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.Control)
    },
)
_sym_db.RegisterMessage(Control)

Save = _reflection.GeneratedProtocolMessageType(
    "Save",
    (_message.Message,),
    {
        "DESCRIPTOR": _SAVE,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.Save)
    },
)
_sym_db.RegisterMessage(Save)

Include = _reflection.GeneratedProtocolMessageType(
    "Include",
    (_message.Message,),
    {
        "DESCRIPTOR": _INCLUDE,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.Include)
    },
)
_sym_db.RegisterMessage(Include)

LibInclude = _reflection.GeneratedProtocolMessageType(
    "LibInclude",
    (_message.Message,),
    {
        "DESCRIPTOR": _LIBINCLUDE,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.LibInclude)
    },
)
_sym_db.RegisterMessage(LibInclude)

Meas = _reflection.GeneratedProtocolMessageType(
    "Meas",
    (_message.Message,),
    {
        "DESCRIPTOR": _MEAS,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.Meas)
    },
)
_sym_db.RegisterMessage(Meas)

Signal = _reflection.GeneratedProtocolMessageType(
    "Signal",
    (_message.Message,),
    {
        "DESCRIPTOR": _SIGNAL,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.Signal)
    },
)
_sym_db.RegisterMessage(Signal)

_SPICE = DESCRIPTOR.services_by_name["Spice"]
if _descriptor._USE_C_DESCRIPTORS == False:

    DESCRIPTOR._options = None
    _DCRESULT_MEASUREMENTSENTRY._options = None
    _DCRESULT_MEASUREMENTSENTRY._serialized_options = b"8\001"
    _TRANINPUT_ICENTRY._options = None
    _TRANINPUT_ICENTRY._serialized_options = b"8\001"
    _TRANRESULT_MEASUREMENTSENTRY._options = None
    _TRANRESULT_MEASUREMENTSENTRY._serialized_options = b"8\001"
    _ACRESULT_MEASUREMENTSENTRY._options = None
    _ACRESULT_MEASUREMENTSENTRY._serialized_options = b"8\001"
    _NOISERESULT_INTEGRATEDNOISEENTRY._options = None
    _NOISERESULT_INTEGRATEDNOISEENTRY._serialized_options = b"8\001"
    _NOISERESULT_MEASUREMENTSENTRY._options = None
    _NOISERESULT_MEASUREMENTSENTRY._serialized_options = b"8\001"
    _SIMINPUT._serialized_start = 57
    _SIMINPUT._serialized_end = 228
    _SIMRESULT._serialized_start = 230
    _SIMRESULT._serialized_end = 282
    _SIMOPTIONS._serialized_start = 284
    _SIMOPTIONS._serialized_end = 371
    _ANALYSIS._serialized_start = 374
    _ANALYSIS._serialized_end = 716
    _ANALYSISRESULT._serialized_start = 719
    _ANALYSISRESULT._serialized_end = 1075
    _OPINPUT._serialized_start = 1077
    _OPINPUT._serialized_end = 1146
    _OPRESULT._serialized_start = 1148
    _OPRESULT._serialized_end = 1224
    _DCINPUT._serialized_start = 1226
    _DCINPUT._serialized_end = 1350
    _DCRESULT._serialized_start = 1353
    _DCRESULT._serialized_end = 1559
    _DCRESULT_MEASUREMENTSENTRY._serialized_start = 1502
    _DCRESULT_MEASUREMENTSENTRY._serialized_end = 1553
    _TRANINPUT._serialized_start = 1562
    _TRANINPUT._serialized_end = 1750
    _TRANINPUT_ICENTRY._serialized_start = 1709
    _TRANINPUT_ICENTRY._serialized_end = 1750
    _TRANRESULT._serialized_start = 1753
    _TRANRESULT._serialized_end = 1949
    _TRANRESULT_MEASUREMENTSENTRY._serialized_start = 1502
    _TRANRESULT_MEASUREMENTSENTRY._serialized_end = 1553
    _COMPLEXNUM._serialized_start = 1951
    _COMPLEXNUM._serialized_end = 1987
    _ACINPUT._serialized_start = 1989
    _ACINPUT._serialized_end = 2103
    _ACRESULT._serialized_start = 2106
    _ACRESULT._serialized_end = 2331
    _ACRESULT_MEASUREMENTSENTRY._serialized_start = 1502
    _ACRESULT_MEASUREMENTSENTRY._serialized_end = 1553
    _NOISEINPUT._serialized_start = 2334
    _NOISEINPUT._serialized_end = 2509
    _NOISERESULT._serialized_start = 2512
    _NOISERESULT._serialized_end = 2839
    _NOISERESULT_INTEGRATEDNOISEENTRY._serialized_start = 2720
    _NOISERESULT_INTEGRATEDNOISEENTRY._serialized_end = 2774
    _NOISERESULT_MEASUREMENTSENTRY._serialized_start = 1502
    _NOISERESULT_MEASUREMENTSENTRY._serialized_end = 1553
    _SWEEPINPUT._serialized_start = 2842
    _SWEEPINPUT._serialized_end = 3002
    _SWEEPRESULT._serialized_start = 3005
    _SWEEPRESULT._serialized_end = 3135
    _MONTEINPUT._serialized_start = 3138
    _MONTEINPUT._serialized_end = 3273
    _MONTERESULT._serialized_start = 3276
    _MONTERESULT._serialized_end = 3406
    _CUSTOMANALYSISINPUT._serialized_start = 3408
    _CUSTOMANALYSISINPUT._serialized_end = 3502
    _CUSTOMANALYSISRESULT._serialized_start = 3504
    _CUSTOMANALYSISRESULT._serialized_end = 3526
    _SWEEP._serialized_start = 3529
    _SWEEP._serialized_end = 3667
    _LINEARSWEEP._serialized_start = 3669
    _LINEARSWEEP._serialized_end = 3725
    _LOGSWEEP._serialized_start = 3727
    _LOGSWEEP._serialized_end = 3780
    _POINTSWEEP._serialized_start = 3782
    _POINTSWEEP._serialized_end = 3838
    _CONTROL._serialized_start = 3841
    _CONTROL._serialized_end = 4065
    _SAVE._serialized_start = 4067
    _SAVE._serialized_end = 4174
    _SAVE_SAVEMODE._serialized_start = 4137
    _SAVE_SAVEMODE._serialized_end = 4166
    _INCLUDE._serialized_start = 4176
    _INCLUDE._serialized_end = 4199
    _LIBINCLUDE._serialized_start = 4201
    _LIBINCLUDE._serialized_end = 4244
    _MEAS._serialized_start = 4246
    _MEAS._serialized_end = 4303
    _SIGNAL._serialized_start = 4305
    _SIGNAL._serialized_end = 4423
    _SIGNAL_QUANTITY._serialized_start = 4377
    _SIGNAL_QUANTITY._serialized_end = 4423
    _SPICE._serialized_start = 4425
    _SPICE._serialized_end = 4486
# @@protoc_insertion_point(module_scope)



"""
# Setup Script

Derived from the setuptools sample project at
https://github.com/pypa/sampleproject/blob/main/setup.py

"""

# Always prefer setuptools over distutils
from setuptools import setup, find_packages
import pathlib

here = pathlib.Path(__file__).parent.resolve()

# Get the long description from the README file
long_description = (here / "readme.md").read_text(encoding="utf-8")

_VLSIR_VERSION = "3.0.1"

setup(
    name="vlsir",
    version=_VLSIR_VERSION,
    description="Data Schemas for Chip Design",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/Vlsir/Vlsir",
    author="Dan Fritchman",
    author_email="dan@fritch.mn",
    packages=find_packages(),
    package_data={
        # Include the primitive protobuf-text literals, which are loaded at runtime
        "vlsir": ["*.pb.txt"]
    },
    python_requires=">=3.7, <4",
    install_requires=["protobuf==3.19.1"],
    extras_require={
        "dev": ["pytest==7.1", "coverage", "pytest-cov", "black==22.6", "twine"]
    },
)



"""
VLSIR Python Bindings 
"""

__version__ = "2.0.dev0"

# Schema
from . import utils_pb2 as utils
from . import spice_pb2 as spice
from . import circuit_pb2 as circuit
from . import raw_pb2 as raw
from . import tetris_pb2 as tetris

# Add the utility-types to the top-level namespace
from .utils_pb2 import *

# But not the other stuff, as quite a few names conflict, e.g. `Library`, `Package`.
# from .spice_pb2 import *
# from .circuit_pb2 import *
# from .raw_pb2 import *
# from .tetris_pb2 import *

# Primitives
from . import primitives



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: circuit.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import utils_pb2 as utils__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\rcircuit.proto\x12\rvlsir.circuit\x1a\x0butils.proto"\x83\x01\n\x07Package\x12\x0e\n\x06\x64omain\x18\x01 \x01(\t\x12&\n\x07modules\x18\x02 \x03(\x0b\x32\x15.vlsir.circuit.Module\x12\x32\n\x0b\x65xt_modules\x18\x03 \x03(\x0b\x32\x1d.vlsir.circuit.ExternalModule\x12\x0c\n\x04\x64\x65sc\x18\n \x01(\t"\x81\x01\n\x04Port\x12\x0e\n\x06signal\x18\x01 \x01(\t\x12\x30\n\tdirection\x18\x02 \x01(\x0e\x32\x1d.vlsir.circuit.Port.Direction"7\n\tDirection\x12\t\n\x05INPUT\x10\x00\x12\n\n\x06OUTPUT\x10\x01\x12\t\n\x05INOUT\x10\x02\x12\x08\n\x04NONE\x10\x03"%\n\x06Signal\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05width\x18\x02 \x01(\x03"1\n\x05Slice\x12\x0e\n\x06signal\x18\x01 \x01(\t\x12\x0b\n\x03top\x18\x02 \x01(\x03\x12\x0b\n\x03\x62ot\x18\x03 \x01(\x03"8\n\x06\x43oncat\x12.\n\x05parts\x18\x01 \x03(\x0b\x32\x1f.vlsir.circuit.ConnectionTarget"z\n\x10\x43onnectionTarget\x12\r\n\x03sig\x18\x01 \x01(\tH\x00\x12%\n\x05slice\x18\x02 \x01(\x0b\x32\x14.vlsir.circuit.SliceH\x00\x12\'\n\x06\x63oncat\x18\x03 \x01(\x0b\x32\x15.vlsir.circuit.ConcatH\x00\x42\x07\n\x05stype"O\n\nConnection\x12\x10\n\x08portname\x18\x01 \x01(\t\x12/\n\x06target\x18\x02 \x01(\x0b\x32\x1f.vlsir.circuit.ConnectionTarget"\x98\x01\n\x08Instance\x12\x0c\n\x04name\x18\x01 \x01(\t\x12&\n\x06module\x18\x02 \x01(\x0b\x32\x16.vlsir.utils.Reference\x12&\n\nparameters\x18\x03 \x03(\x0b\x32\x12.vlsir.utils.Param\x12.\n\x0b\x63onnections\x18\x04 \x03(\x0b\x32\x19.vlsir.circuit.Connection"\xb6\x01\n\x06Module\x12\x0c\n\x04name\x18\x01 \x01(\t\x12"\n\x05ports\x18\x02 \x03(\x0b\x32\x13.vlsir.circuit.Port\x12&\n\x07signals\x18\x03 \x03(\x0b\x32\x15.vlsir.circuit.Signal\x12*\n\tinstances\x18\x04 \x03(\x0b\x32\x17.vlsir.circuit.Instance\x12&\n\nparameters\x18\x05 \x03(\x0b\x32\x12.vlsir.utils.Param"\xbc\x01\n\x0e\x45xternalModule\x12(\n\x04name\x18\x01 \x01(\x0b\x32\x1a.vlsir.utils.QualifiedName\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\x12"\n\x05ports\x18\x03 \x03(\x0b\x32\x13.vlsir.circuit.Port\x12&\n\x07signals\x18\x04 \x03(\x0b\x32\x15.vlsir.circuit.Signal\x12&\n\nparameters\x18\x05 \x03(\x0b\x32\x12.vlsir.utils.Param"=\n\tInterface\x12\x0c\n\x04name\x18\x01 \x01(\t\x12"\n\x05ports\x18\n \x03(\x0b\x32\x13.vlsir.circuit.Portb\x06proto3'
)


_PACKAGE = DESCRIPTOR.message_types_by_name["Package"]
_PORT = DESCRIPTOR.message_types_by_name["Port"]
_SIGNAL = DESCRIPTOR.message_types_by_name["Signal"]
_SLICE = DESCRIPTOR.message_types_by_name["Slice"]
_CONCAT = DESCRIPTOR.message_types_by_name["Concat"]
_CONNECTIONTARGET = DESCRIPTOR.message_types_by_name["ConnectionTarget"]
_CONNECTION = DESCRIPTOR.message_types_by_name["Connection"]
_INSTANCE = DESCRIPTOR.message_types_by_name["Instance"]
_MODULE = DESCRIPTOR.message_types_by_name["Module"]
_EXTERNALMODULE = DESCRIPTOR.message_types_by_name["ExternalModule"]
_INTERFACE = DESCRIPTOR.message_types_by_name["Interface"]
_PORT_DIRECTION = _PORT.enum_types_by_name["Direction"]
Package = _reflection.GeneratedProtocolMessageType(
    "Package",
    (_message.Message,),
    {
        "DESCRIPTOR": _PACKAGE,
        "__module__": "circuit_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.circuit.Package)
    },
)
_sym_db.RegisterMessage(Package)

Port = _reflection.GeneratedProtocolMessageType(
    "Port",
    (_message.Message,),
    {
        "DESCRIPTOR": _PORT,
        "__module__": "circuit_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.circuit.Port)
    },
)
_sym_db.RegisterMessage(Port)

Signal = _reflection.GeneratedProtocolMessageType(
    "Signal",
    (_message.Message,),
    {
        "DESCRIPTOR": _SIGNAL,
        "__module__": "circuit_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.circuit.Signal)
    },
)
_sym_db.RegisterMessage(Signal)

Slice = _reflection.GeneratedProtocolMessageType(
    "Slice",
    (_message.Message,),
    {
        "DESCRIPTOR": _SLICE,
        "__module__": "circuit_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.circuit.Slice)
    },
)
_sym_db.RegisterMessage(Slice)

Concat = _reflection.GeneratedProtocolMessageType(
    "Concat",
    (_message.Message,),
    {
        "DESCRIPTOR": _CONCAT,
        "__module__": "circuit_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.circuit.Concat)
    },
)
_sym_db.RegisterMessage(Concat)

ConnectionTarget = _reflection.GeneratedProtocolMessageType(
    "ConnectionTarget",
    (_message.Message,),
    {
        "DESCRIPTOR": _CONNECTIONTARGET,
        "__module__": "circuit_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.circuit.ConnectionTarget)
    },
)
_sym_db.RegisterMessage(ConnectionTarget)

Connection = _reflection.GeneratedProtocolMessageType(
    "Connection",
    (_message.Message,),
    {
        "DESCRIPTOR": _CONNECTION,
        "__module__": "circuit_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.circuit.Connection)
    },
)
_sym_db.RegisterMessage(Connection)

Instance = _reflection.GeneratedProtocolMessageType(
    "Instance",
    (_message.Message,),
    {
        "DESCRIPTOR": _INSTANCE,
        "__module__": "circuit_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.circuit.Instance)
    },
)
_sym_db.RegisterMessage(Instance)

Module = _reflection.GeneratedProtocolMessageType(
    "Module",
    (_message.Message,),
    {
        "DESCRIPTOR": _MODULE,
        "__module__": "circuit_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.circuit.Module)
    },
)
_sym_db.RegisterMessage(Module)

ExternalModule = _reflection.GeneratedProtocolMessageType(
    "ExternalModule",
    (_message.Message,),
    {
        "DESCRIPTOR": _EXTERNALMODULE,
        "__module__": "circuit_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.circuit.ExternalModule)
    },
)
_sym_db.RegisterMessage(ExternalModule)

Interface = _reflection.GeneratedProtocolMessageType(
    "Interface",
    (_message.Message,),
    {
        "DESCRIPTOR": _INTERFACE,
        "__module__": "circuit_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.circuit.Interface)
    },
)
_sym_db.RegisterMessage(Interface)

if _descriptor._USE_C_DESCRIPTORS == False:

    DESCRIPTOR._options = None
    _PACKAGE._serialized_start = 46
    _PACKAGE._serialized_end = 177
    _PORT._serialized_start = 180
    _PORT._serialized_end = 309
    _PORT_DIRECTION._serialized_start = 254
    _PORT_DIRECTION._serialized_end = 309
    _SIGNAL._serialized_start = 311
    _SIGNAL._serialized_end = 348
    _SLICE._serialized_start = 350
    _SLICE._serialized_end = 399
    _CONCAT._serialized_start = 401
    _CONCAT._serialized_end = 457
    _CONNECTIONTARGET._serialized_start = 459
    _CONNECTIONTARGET._serialized_end = 581
    _CONNECTION._serialized_start = 583
    _CONNECTION._serialized_end = 662
    _INSTANCE._serialized_start = 665
    _INSTANCE._serialized_end = 817
    _MODULE._serialized_start = 820
    _MODULE._serialized_end = 1002
    _EXTERNALMODULE._serialized_start = 1005
    _EXTERNALMODULE._serialized_end = 1193
    _INTERFACE._serialized_start = 1195
    _INTERFACE._serialized_end = 1256
# @@protoc_insertion_point(module_scope)
